
# THIS FILE IS GENERATED FROM PYRAD_PROC SETUP.PY
short_version = '1.3.3'
version = '1.3.3'
full_version = '1.3.3'
git_revision = '74e6d5229e502c56ca4a1499194307100dc0a5bd'
compile_date_time = '2022-08-17 10:21'
username = 'wolfensb'
release = True

if not release:
    version = full_version
